@@ -1,26 +1,25 @@
-'''
-MIT License
+# MIT License
 
-Copyright (c) 2022 Beksultan Artykbaev
+# Copyright (c) 2022 Beksultan Artykbaev
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
-'''
 import string
 import random
 from secrets import choice
@@ -32,8 +31,9 @@ def generate_nick(
 	vowel_graphems = ['eir', 'ay', 'eau', 'au', 'ayer', 'ei', 'igh', 'aw', 'ow', 'ore', 'ou', 'er', 'ae', 'augh', 'ough', 'oo', 'uoy', 'oar', 'our', 'eer', 'et', 'eigh', 'ey', 'ye', 'ai', 'ew', 'eo', 'uy', 'u', 'air', 'oew', 'oa', 'ur', 'oe', 'ie', 'are', 'ir', 'ea', 'oy', 'aigh', 'or', 'ui', 'yr', 'ar', 'oor', 'ier', 'ue', 'ee', 'oi', 'ear', 'ho', 'ure', 'is', 'ere'],
 	consonant_graphems = ['rr', 'sh', 'th', 'gu', 'zz', 'ff', 'sc', 'ft', 'dd', 'wr', 'tt', 'tu', 'qu', 'rh', 'ss', 'bb', 'lm', 'pn', 'pp', 'lf', 'se', 'mn', 'ti', 'll', 'ph', 'ps', 'te', 'kn', 'ch', 'mm', 'ck', 'gh', 'gn', 'wh', 'ed', 'mb', 'sci', 'si', 'dge', 've', 'ce', 'cc', 'ge', 'st', 'lk', 'gg', 'tch', 'ze', 'gue', 'nn', 'ci', 'di'],
 	consonants = ['b', 'c', 'd', 'f', 'g', 'h', 'j', 'k', 'l', 'm', 'n', 'p', 'q', 'r', 's', 't', 'v', 'w', 'x', 'y', 'z']) -> str:
-	'''Generate nicknames by inputed vowels, consonants, and other sounds.'''
-
+	'''Generate nickname by inputed vowels, consonants, and other sounds.'''
+	if length == 0:
+		return ""
 	# Picking the first letter of name
 	nickname = random.choice(random.choice([vowels, consonants]))
 	previous_char = nickname
@@ -57,8 +57,8 @@ def generate_nick(
 			nickname += char
 	return nickname.capitalize()
 
-class Generate_password():
-	"""Returns randomized password by input settings
+class GeneratePassword():
+	"""Returns generated by input settings password
 	Character:
 		Function contains 2 character bundles:
 				- english
@@ -74,19 +74,18 @@ class Generate_password():
 	If both of them turned off, it will use it's default settings (Uppercase), and it won't change inputed chars.
 	"""
 
-	similar_chars = ["1", "L", "O", "0", '"', "'", "I", "B", "6", "|"]
 
 	def __init__(self, length: int = 12,
 			english: bool = True, symbols: bool = True,  numerals: bool = True,
 			own_symbols = "", exclude_similarities: bool = False,
-			lowercase: bool = True, uppercase: bool = True) -> str:
+			lowercase: bool = True, uppercase: bool = True, similar_chars: List = ["1", "L", "O", "0", '"', "'", "I", "B", "6", "|"]) -> str:
 
 		self.length = length
 		self.english = english
 		self.symbols = symbols
 		self.numerals = numerals
 		self.own_symbols = own_symbols
-
+		self.similar_chars = similar_chars
 		self.exclude_similarities = exclude_similarities
 		self.lowercase = lowercase
 		self.uppercase = uppercase
@@ -107,7 +106,7 @@ class Generate_password():
 
 			# Excluding similar characters if it's set to True
 			if self.exclude_similarities:
-				self.__exclude_similar(main_list, Generate_password.similar_chars)
+				self.__exclude_similar(main_list, self.similar_chars)
 
 
 			password_holder = ""
